def parse_json(resp_json: dict, keyword: str) -> list:
    final_list = []
    tweets = resp_json['globalObjects']['tweets']
    for tweet_id in tweets.keys():
        dict = {}
        dict["id"] = tweet_id
        dict['created_at'] = tweets[tweet_id]['created_at']
        dict['full_text'] = tweets[tweet_id]['text']
        dict['source'] = tweets[tweet_id]['source']
        dict['user_id'] = tweets[tweet_id]['user_id_str']
        dict['geo'] = tweets[tweet_id]['geo']
        dict['retweet_count'] = tweets[tweet_id]['retweet_count']
        dict['favorite_count'] = tweets[tweet_id]['favorite_count']
        dict["search_keyword"] = keyword
        final_list.append(dict)
    return final_list



""" __Doc__ File handle class """
from setuptools import find_packages, setup

from XOTweet.__version__ import __version__


def dependencies(imported_file):
    """ __Doc__ Handles dependencies """
    with open(imported_file) as file:
        return file.read().splitlines()


with open("README.md") as file:
    setup(
        name="XOTweet",
        license="GPLv3",
        description="XOTweet is a tweet bot that scraps twitter for keywords and returns all valid tweets",
        long_description=file.read(),
        author="Akhil Reni",
        version=__version__,
        author_email="akhil@wesecureapp.com",
        url="https://strobes.co/",
        packages=find_packages(
            exclude=('tests')),
        package_data={
            'XOTweet': [
                '*.txt',
                '*.json']},
        entry_points={
            'console_scripts': ['xo_tweet = XOTweet.xo_tweet:main']},
        include_package_data=True)



AUTHORIZATION_TOKEN = "AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs=1Zv7ttfk8LF81IUq16cHj" \
                      "hLTvJu4FA33AGWWjCpTnA"

GUEST_TOKEN_URL = "https://api.twitter.com/1.1/guest/activate.json"

SEARCH_URL = "https://api.twitter.com/2/search/adaptive.json?q={}&query_source=typed_query"

LOGGING_CONFIG = {
    'disable_existing_loggers': False,
    'version': 1,
    'formatters': {
        'short': {
            'format': '%(asctime)s %(levelname)s %(name)s: %(message)s'
        },
    },
    'handlers': {
        'console': {
            'level': 'INFO',
            'formatter': 'short',
            'class': 'logging.StreamHandler',
        },
    },
    'loggers': {
        '': {
            'handlers': ['console'],
            'level': 'INFO',
        },
        'plugins': {
            'handlers': ['console'],
            'level': 'INFO',
            'propagate': False
        }
    },
}



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import asyncio
import logging
from datetime import datetime, timedelta
from typing import Any

import requests
from dateutil.rrule import rrule, MONTHLY
from requests.utils import requote_uri

from XOTweet.core.exceptions import WrongStatusCodeException
from XOTweet.core.parser import parse_json
from XOTweet.core.settings import SEARCH_URL
from XOTweet.core.utils import get_headers, form_query
from XOTweet.core.workers import TaskExecuter

logger = logging.getLogger(__name__)


def get_results(keyword, exclude: list = "", from_date: str = "", till_date: str = "") -> Any:
    cursor = ''
    query = form_query(keyword, exclude, from_date, till_date)
    logger.info("[+] Query received {}".format(query))
    tweet_ids = []
    while True:
        try:
            url = SEARCH_URL.format(query) + "&cursor={}".format(cursor)
            url = requote_uri(url)
            resp = requests.get(url=url, headers=get_headers())
            if resp.status_code == 200:
                tweet_json = resp.json()
                try:
                    cursor = tweet_json['timeline']['instructions'][0]['addEntries']['entries'][-1]['content'] \
                        ['operation']['cursor']['value']
                except Exception as e:
                    cursor = tweet_json['timeline']['instructions'][-1]['replaceEntry']['entry']['content'] \
                        ['operation']['cursor']['value']
                parsed_json = parse_json(tweet_json, keyword)
                tweets = tweet_json['globalObjects']['tweets']
                if len(tweets) != 0 and list(tweets.keys())[0] not in tweet_ids:
                    tweet_ids.extend(tweets.keys())
                else:
                    break
            else:
                raise WrongStatusCodeException
        except Exception as e:
            logger.error(e)
            raise e
    return parsed_json


def scrapper(keyword: str, exclude: list = [], dates: list = None, threads=5) -> list:
    task_obj = TaskExecuter(threads)
    if not dates:
        start = datetime(2019, 1, 1).date()
        end = datetime.now().date() + timedelta(weeks=+4)
        dates = [dt.date() for dt in rrule(MONTHLY, dtstart=start, until=end)]
    # Calling scraper on each month date range
    from_date = dates.pop(0)
    for d in dates:
        task_obj.add_task(task_obj.execute_task(get_results, keyword=keyword, exclude=exclude,
                                                from_date=from_date.strftime("%Y-%m-%d"),
                                                till_date=d.strftime("%Y-%m-%d")))

    asyncio.run(task_obj.app())
    final_list = []
    for result in task_obj.results:
        for r in result:
            final_list.extend(r)
    logger.info(final_list)
    return final_list



import logging.config
from datetime import datetime, timedelta

from dateutil.rrule import rrule, MONTHLY

from XOTweet.core.scrap import scrapper
from XOTweet.core.settings import LOGGING_CONFIG
from XOTweet.input import parse_args


def main():
    logging.config.dictConfig(LOGGING_CONFIG)
    logger = logging.getLogger(__name__)
    print("""
         _  _  _____     ____  _    _  ____  ____  ____ 
        ( \/ )(  _  )___(_  _)( \/\/ )( ___)( ___)(_  _)
         )  (  )(_)((___) )(   )    (  )__)  )__)   )(  
        (_/\_)(_____)    (__) (__/\__)(____)(____) (__) 
        """)

    # Parsing Input Arguments
    arguments, unknown = parse_args()
    # Dividing the date into months
    if arguments.From_Date:
        start = arguments.From_Date
        end = datetime.now() + timedelta(weeks=+4)
        dates = [dt for dt in rrule(MONTHLY, dtstart=start, until=end)]
    else:
        start = datetime(2019, 1, 1).date()
        end = datetime.now().date() + timedelta(weeks=+4)
        dates = [dt.date() for dt in rrule(MONTHLY, dtstart=start, until=end)]

    final_list = scrapper(arguments.Keyword, arguments.Exclude, dates, arguments.Threads)

    return final_list


if __name__ == "__main__":
    main()
